/* Scheduler includes. */
#include "FreeRTOSConfig.h"
#include "FreeRTOS.h"
#include "task.h"

#include "stm32f10x.h"
#include "stm32f10x_rcc.h"
#include "stm32f10x_gpio.h"
#include "misc.h"

/* Functions ------------------------------------------------------------------*/
void vTask1(void* pvParameters);

// D13 = LED1 on OLIMEXINO-STM32 (pin 21), PA5
// D3  = LED2 on OLIMEXINO-STM32 (pin 15), PA1
int main(void) {
#if defined(OLIMEXINO)
	RCC->APB2ENR = RCC_APB2ENR_IOPAEN; // enable clock for peripheral block A
	GPIOA->CRL = GPIO_CRL_MODE1 | GPIO_CRL_MODE5; // enable LED1 and LED2 as outputs

	GPIOA->BSRR = GPIO_BSRR_BR1; // clear LED1 status
	GPIOA->BSRR = GPIO_BSRR_BR5; // clear LED2 status
#elif defined (STM32F10X_MD_VL)
	RCC->APB2ENR = RCC_APB2ENR_IOPCEN; // enable clock for peripheral block A
	GPIOC->CRH = GPIO_CRH_MODE8 | GPIO_CRH_MODE9; // enable LED1 and LED2 as outputs

	GPIOC->BSRR = GPIO_BSRR_BR8; // clear LED1 status
	GPIOC->BSRR = GPIO_BSRR_BR9; // clear LED2 status
#endif

	//Create Task
	xTaskCreate(vTask1, "Task1", 256, NULL, 1, NULL);

	//Run Scheduler
	vTaskStartScheduler();

	//This infinite loop is just in case something goes wrong
	for(;;);
}

void vTask1 (void* pvParameters)
{
	volatile int i;
	int bOn = 0;
	const portTickType xDelay = 500 / portTICK_RATE_MS; // Block for 500ms.
	while (1)
	{
		if (!bOn)
		{
#if defined(OLIMEXINO)
			GPIOA->BSRR = GPIO_BSRR_BS1; // LED1 ON
			GPIOA->BSRR = GPIO_BSRR_BR5; // LED2 OFF
#elif defined (STM32F10X_MD_VL)
			GPIOC->BSRR = GPIO_BSRR_BS8; // LED4 ON
			GPIOC->BSRR = GPIO_BSRR_BR9; // LED3 OFF
#endif
		}
		else
		{
#if defined(OLIMEXINO)
			GPIOA->BSRR = GPIO_BSRR_BR1; // LED1 OFF
			GPIOA->BSRR = GPIO_BSRR_BS5; // LED2 OFF
#elif defined (STM32F10X_MD_VL)
			GPIOC->BSRR = GPIO_BSRR_BR8; // LED4 OFF
			GPIOC->BSRR = GPIO_BSRR_BS9; // LED3 ON
#endif
		}
		bOn = !bOn;
		vTaskDelay( xDelay );
	}
}
